NAME
Task::WebDyne::PAGI - Install PAGI dependencies for WebDyne
SYNOPSIS
cpan Task::WebDyne::PAGI
cpanm Task::WebDyne::PAGI
DESCRIPTION
Task::WebDyne::PAGI installs the Perl modules required to use PAGI with WebDyne.
AUTHOR
Andrew Speer andrew.speer@isolutions.com.au
LICENSE and COPYRIGHT
This file is part of Task::WebDyne::PAGI.
This software is copyright (c) 2026 by Andrew Speer mailto:andrew.speer@isolutions.com.au.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
Full license text is available at: